==> wow_views-0.0.80.tar.gz: lib/components/wow_app_bar.dart <==
import 'package:flutter/material.dart';
import 'package:wow_views/common/text_style.dart';

import 'wow_text.dart';

class WowAppBar extends AppBar {
  WowAppBar({
    super.key,
    super.titleTextStyle,
    super.toolbarTextStyle,
    super.backgroundColor,
    super.elevation,
    super.centerTitle,
    super.leadingWidth,
    super.actions,
    super.bottom,
    super.flexibleSpace,
    super.toolbarHeight,
    String? title,
    Color? color,
    Function()? onTapBack,
    Widget? titleWidget,
    Widget? leading,
    bool hasLeading = true,
  }) : super(
          leading: hasLeading
              ? (leading ??
                  Align(
                    alignment: Alignment.centerLeft,
                    child: WowBackButton(
                      color: color,
                      onPressed: onTapBack,
                    ),
                  ))
              : null,
          title: titleWidget ??
              WowText(
                title,
                style: titleTextStyle ?? WowTextStyle.title,
                textAlign:
                    (centerTitle ?? true) ? TextAlign.center : TextAlign.start,
              ),
          automaticallyImplyLeading: false,
        );
}

class WowBackButton extends StatelessWidget {
  const WowBackButton({
    super.key,
    this.color,
    this.onPressed,
    this.canPop,
  });

  final Color? color;

  final Function? onPressed;

  final bool? canPop;

  @override
  Widget build(BuildContext context) {
    assert(debugCheckHasMaterialLocalizations(context));
    final ModalRoute<dynamic>? parentRoute = ModalRoute.of(context);

    bool _canPop = canPop ?? parentRoute?.canPop ?? false;

    if (!_canPop) {
      return const SizedBox.shrink();
    }
    return IconButton(
      icon: Icon(
        Icons.arrow_back_ios_rounded,
        color: color ?? Theme.of(context).appBarTheme.iconTheme?.color,
        size: 24.0,
      ),
      color: color,
      tooltip: MaterialLocalizations.of(context).backButtonTooltip,
      onPressed: () {
        if (onPressed != null) {
          onPressed!();
        } else {
          Navigator.maybePop(context);
        }
      },
    );
  }
}

==> wow_views-0.1.7.tar.gz: lib/components/wow_app_bar.dart <==
import 'package:flutter/material.dart';
import 'package:wow_views/common/text_style.dart';

import 'wow_text.dart';

class WowAppBar extends AppBar {
  WowAppBar({
    super.key,
    super.titleTextStyle,
    super.toolbarTextStyle,
    super.backgroundColor,
    super.elevation,
    super.centerTitle,
    super.leadingWidth,
    super.actions,
    super.bottom,
    super.flexibleSpace,
    super.toolbarHeight,
    String? title,
    Color? color,
    Function()? onTapBack,
    Widget? titleWidget,
    Widget? leading,
    bool hasLeading = true,
  }) : super(
          leading: hasLeading
              ? (leading ??
                  Align(
                    alignment: Alignment.centerLeft,
                    child: WowBackButton(
                      color: color,
                      onPressed: onTapBack,
                    ),
                  ))
              : null,
          title: titleWidget ??
              WowText(
                title,
                style: titleTextStyle ?? WowTextStyle.title,
                textAlign:
                    (centerTitle ?? true) ? TextAlign.center : TextAlign.start,
              ),
          automaticallyImplyLeading: false,
        );
}

class WowBackButton extends StatelessWidget {
  const WowBackButton({
    super.key,
    this.color,
    this.onPressed,
    this.canPop,
  });

  final Color? color;

  final Function? onPressed;

  final bool? canPop;

  @override
  Widget build(BuildContext context) {
    assert(debugCheckHasMaterialLocalizations(context));
    final ModalRoute<dynamic>? parentRoute = ModalRoute.of(context);

    bool check = canPop ?? parentRoute?.canPop ?? false;

    if (!check) {
      return const SizedBox.shrink();
    }
    return IconButton(
      icon: Icon(
        Icons.arrow_back_ios_rounded,
        color: color ?? Theme.of(context).appBarTheme.iconTheme?.color,
        size: 24.0,
      ),
      color: color,
      tooltip: MaterialLocalizations.of(context).backButtonTooltip,
      onPressed: () {
        if (onPressed != null) {
          onPressed!();
        } else {
          Navigator.maybePop(context);
        }
      },
    );
  }
}
